@@ -4,3 +4,5 @@ from .iql import IQLPolicy
 from .sac import SACPolicy
 from .sacn import SACNPolicy
 from .xql import XQLPolicy
+from .td3 import TD3Policy
+from .td3bc import TD3BCPolicy
\ No newline at end of file
